@@ -1,6 +1,6 @@
 import os
 from pathlib import Path
-from typing import Any, Optional, Tuple, Union, cast
+from typing import Any, Optional, Tuple, cast
 
 import click
 from robot.errors import DataError, Information
@@ -28,7 +28,7 @@ class RebotEx(Rebot):
             raise Information(
                 "Dry run, not executing any commands. "
                 f"Would execute libdoc with the following options and arguments:\n"
-                f'{line_end.join((*(f"{k} = {repr(v)}" for k, v in options.items()) ,*arguments))}'
+                f'{line_end.join((*(f"{k} = {v!r}" for k, v in options.items()) ,*arguments))}'
             )
 
         return options, arguments
@@ -37,7 +37,7 @@ class RebotEx(Rebot):
         if self.root_folder is not None:
             os.chdir(self.root_folder)
 
-        super().main(arguments, **options)
+        return super().main(arguments, **options)
 
 
 @click.command(
@@ -46,7 +46,7 @@ class RebotEx(Rebot):
         "ignore_unknown_options": True,
     },
     add_help_option=True,
-    # short_help='Runs "rebot" with the selected configuration, profiles, options and arguments.',
+    epilog='Use "-- --help" to see `rebot` help.',
 )
 @click.version_option(
     version=__version__,
@@ -59,12 +59,10 @@ class RebotEx(Rebot):
 def rebot(
     app: Application,
     robot_options_and_args: Tuple[str, ...],
-) -> Union[str, int, None]:
-    """Runs "rebot" with the selected configuration, profiles, options and arguments.
+) -> None:
+    """Runs `rebot` with the selected configuration, profiles, options and arguments.
 
-    The options and arguments are passed to "rebot" as is.
-
-    Use "-- --help" to see the rebot help.
+    The options and arguments are passed to `rebot` as is.
     """
 
     robot_arguments = None
@@ -102,14 +100,14 @@ def rebot(
             os.environ[k] = v
             app.verbose(lambda: f"Set environment variable {k} to {v}")
 
-    try:
-        app.verbose(
-            lambda: "Executing rebot with the following options:\n    "
-            + " ".join(f'"{o}"' for o in (options + list(robot_options_and_args)))
-        )
-        return cast(
+    app.verbose(
+        lambda: "Executing rebot with the following options:\n    "
+        + " ".join(f'"{o}"' for o in (options + list(robot_options_and_args)))
+    )
+
+    app.exit(
+        cast(
             int,
             RebotEx(app.config.dry, root_folder).execute_cli((*options, *robot_options_and_args), exit=False),
         )
-    except SystemExit as e:
-        return cast(int, e.code)
+    )
